updatetools
===========

.. automodule:: abjad.tools.updatetools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.updatetools.UpdateManager.UpdateManager.UpdateManager
